/**
 * EasyBeans
 * Copyright (C) 2007 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: FrameworkManagerHelper.java 1941 2007-10-14 17:57:14Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.osgi.plugins.launcher;

import org.ow2.easybeans.osgi.plugins.launcher.api.IFramework;

/**
 * Build a new Framework manager for a given configuration.
 * @author Florent BENOIT
 */
public final class FrameworkManagerHelper {

    /**
     * Utility class.
     */
    private FrameworkManagerHelper() {

    }

    /**
     * Gets a framework manager for the given configuration.
     * @param configuration the given configuration
     * @return a newly framework manager
     * @throws FrameworkManagerException if the framework manager is not built.
     */
    @SuppressWarnings("unchecked")
    public static FrameworkManager getFrameworkManager(final Configuration configuration) throws FrameworkManagerException {
        // Build a new FrameWork object using reflection (to avoid a direct dependency)
        String frameworkClassname = configuration.getFrameworkClassname();
        ClassLoader classLoader = Thread.currentThread().getContextClassLoader();

        // Load the class
        Class<IFramework> frameworkClass = null;
        try {
            frameworkClass = (Class<IFramework>) classLoader.loadClass(frameworkClassname);
        } catch (ClassNotFoundException e) {
            throw new FrameworkManagerException("Cannot load the framework with the classname " + frameworkClassname, e);
        } catch (ClassCastException e) {
            throw new FrameworkManagerException("Cannot load the framework with the classname " + frameworkClassname, e);
        }

        // Build framework object
        IFramework framework = null;
        try {
            framework = frameworkClass.newInstance();
        } catch (InstantiationException e) {
            throw new FrameworkManagerException("Cannot build instance of the class " + frameworkClass, e);
        } catch (IllegalAccessException e) {
            throw new FrameworkManagerException("Cannot build instance of the class " + frameworkClass, e);
        }

        // Now, can build framework manager
        FrameworkManager frameworkManager = new FrameworkManager();

        // Sets the configuration
        frameworkManager.setConfiguration(configuration);
        frameworkManager.setFramework(framework);

        return frameworkManager;
    }
}
